@@ -71,6 +71,13 @@ impl ConversionType {
                 Filename => Self::Pointer,
                 OsString => Self::Pointer,
                 Type => Self::Scalar,
+                TimeT => Self::Direct,
+                OffT => Self::Direct,
+                DevT => Self::Direct,
+                GidT => Self::Direct,
+                PidT => Self::Direct,
+                SockLenT => Self::Direct,
+                UidT => Self::Direct,
                 None => Self::Unknown,
                 IntPtr => Self::Direct,
                 UIntPtr => Self::Direct,
