@@ -98,6 +98,8 @@ pub struct Info {
     /// this potential global function is defined
     pub ns_id: NsId,
     pub generate_doc: bool,
+    pub get_property: Option<String>,
+    pub set_property: Option<String>,
 }
 
 impl Info {
@@ -110,7 +112,7 @@ impl Info {
             .trim_end_matches('_')
             .rsplit('_')
             .next()
-            .map_or(false, |i| i.parse::<special_functions::Type>().is_ok())
+            .is_some_and(|i| i.parse::<special_functions::Type>().is_ok())
     }
 
     // returns whether the method can be linked in the docs
@@ -558,9 +560,10 @@ fn analyze_function(
 ) -> Info {
     let ns_id = type_tid.map_or(MAIN_NAMESPACE, |t| t.ns_id);
     let type_tid = type_tid.unwrap_or_default();
-    let r#async = func.parameters.iter().any(|parameter| {
-        parameter.scope == ParameterScope::Async && parameter.c_type == "GAsyncReadyCallback"
-    });
+    let r#async = func.finish_func.is_some()
+        || func.parameters.iter().any(|parameter| {
+            parameter.scope == ParameterScope::Async && parameter.c_type == "GAsyncReadyCallback"
+        });
     let has_callback_parameter = !r#async
         && func
             .parameters
@@ -890,6 +893,8 @@ fn analyze_function(
             }
         }
 
+        imports.add("crate::ffi");
+
         imports.add_used_types(&used_types);
         if ret.base_tid.is_some() {
             imports.add("glib::prelude::*");
@@ -942,6 +947,8 @@ fn analyze_function(
         hidden: false,
         ns_id,
         generate_doc,
+        get_property: func.get_property.clone(),
+        set_property: func.set_property.clone(),
     }
 }
 
@@ -978,7 +985,11 @@ fn analyze_async(
         // Checks for /*Ignored*/ or other error comments
         *commented |= callback_type.contains("/*");
         let func_name = func.c_identifier.as_ref().unwrap();
-        let finish_func_name = finish_function_name(func_name);
+        let finish_func_name = if let Some(finish_func_name) = &func.finish_func {
+            finish_func_name.to_string()
+        } else {
+            finish_function_name(func_name)
+        };
         let mut output_params = vec![];
         let mut ffi_ret = None;
         if let Some(function) = find_function(env, &finish_func_name) {
