@@ -44,7 +44,10 @@ macro_rules! impl_to_stripper_type {
             fn to_stripper_type(&self) -> TypeStruct {
                 TypeStruct::new(
                     SType::$enum_var,
-                    &format!("connect_{}", nameutil::signal_to_snake(&self.name)),
+                    &format!(
+                        "connect_{}",
+                        nameutil::mangle_keywords(nameutil::signal_to_snake(&self.name))
+                    ),
                 )
             }
         }
@@ -52,7 +55,7 @@ macro_rules! impl_to_stripper_type {
     ($ty:ident, $enum_var:ident) => {
         impl ToStripperType for $ty {
             fn to_stripper_type(&self) -> TypeStruct {
-                TypeStruct::new(SType::$enum_var, &self.name)
+                TypeStruct::new(SType::$enum_var, &nameutil::mangle_keywords(&self.name))
             }
         }
     };
@@ -192,8 +195,7 @@ fn generate_doc(w: &mut dyn Write, env: &Env) -> Result<()> {
                     .map(|analyzed_f| analyzed_f.doc_ignore_parameters.clone())
                     .unwrap_or_default();
 
-                let should_be_documented =
-                    f_info.map_or(false, |f| f.should_docs_be_generated(env));
+                let should_be_documented = f_info.is_some_and(|f| f.should_docs_be_generated(env));
                 if !should_be_documented {
                     continue;
                 }
@@ -402,6 +404,9 @@ fn create_object_doc(w: &mut dyn Write, env: &Env, info: &analysis::object::Info
             }
         }
         for property in &builder_properties {
+            if !property.writable {
+                continue;
+            }
             let ty = TypeStruct {
                 ty: SType::Fn,
                 name: nameutil::signal_to_snake(&property.name),
@@ -506,7 +511,7 @@ fn create_object_doc(w: &mut dyn Write, env: &Env, info: &analysis::object::Info
         };
         if let Some(c_identifier) = &function.c_identifier {
             let f_info = info.functions.iter().find(|f| &f.glib_name == c_identifier);
-            let should_be_documented = f_info.map_or(false, |f| f.should_docs_be_generated(env));
+            let should_be_documented = f_info.is_some_and(|f| f.should_docs_be_generated(env));
 
             if !should_be_documented {
                 continue;
@@ -581,7 +586,7 @@ fn create_object_doc(w: &mut dyn Write, env: &Env, info: &analysis::object::Info
                 .virtual_methods
                 .iter()
                 .find(|f| &f.glib_name == c_identifier);
-            let should_be_documented = f_info.map_or(false, |f| f.should_docs_be_generated(env));
+            let should_be_documented = f_info.is_some_and(|f| f.should_docs_be_generated(env));
             if !should_be_documented {
                 continue;
             }
@@ -605,19 +610,25 @@ fn create_object_doc(w: &mut dyn Write, env: &Env, info: &analysis::object::Info
     }
 
     for property in properties {
-        let getter_name = info
-            .properties
-            .iter()
-            .filter(|p| p.is_get)
-            .find(|p| p.name == property.name)
-            .map(|p| p.func_name.clone());
+        let getter_name = if property.getter.is_some() {
+            None // Don't generate a getter for the property, there is a getter
+        } else {
+            info.properties
+                .iter()
+                .filter(|p| p.is_get)
+                .find(|p| p.name == property.name)
+                .map(|p| p.func_name.clone())
+        };
+        let setter_name = if property.setter.is_some() {
+            None // don't generate a setter for the property, there is a setter
+        } else {
+            info.properties
+                .iter()
+                .filter(|p| !p.is_get)
+                .find(|p| p.name == property.name)
+                .map(|p| p.func_name.clone())
+        };
 
-        let setter_name = info
-            .properties
-            .iter()
-            .filter(|p| !p.is_get)
-            .find(|p| p.name == property.name)
-            .map(|p| p.func_name.clone());
         let (ty, object_location) = if has_trait {
             let configured_properties = obj.properties.matched(&property.name);
             if let Some(trait_name) = configured_properties
@@ -683,7 +694,7 @@ fn create_record_doc(w: &mut dyn Write, env: &Env, info: &analysis::record::Info
         };
         if let Some(c_identifier) = &function.c_identifier {
             let f_info = info.functions.iter().find(|f| &f.glib_name == c_identifier);
-            let should_be_documented = f_info.map_or(false, |f| f.should_docs_be_generated(env));
+            let should_be_documented = f_info.is_some_and(|f| f.should_docs_be_generated(env));
             if !should_be_documented {
                 continue;
             }
@@ -731,7 +742,7 @@ fn create_enum_doc(w: &mut dyn Write, env: &Env, enum_: &Enumeration, tid: TypeI
                 m.members
                     .matched(&member.name)
                     .first()
-                    .map(|m| m.generate_doc)
+                    .map(|m| m.generate_doc && !m.status.ignored())
             })
             .unwrap_or(true);
 
@@ -860,7 +871,7 @@ where
 
     let mut st = fn_.to_stripper_type();
     if let Some(name_override) = name_override {
-        st.name = name_override;
+        st.name = nameutil::mangle_keywords(name_override).to_string();
     }
     let ty = TypeStruct { parent, ..st };
     let self_name: Option<String> = fn_
@@ -1006,26 +1017,15 @@ fn create_property_doc(
     {
         return Ok(());
     }
-    let name_for_func = nameutil::signal_to_snake(&property.name);
-    let getter_name = getter_name.unwrap_or_else(|| name_for_func.clone());
-    let has_getter_method = obj_info.functions.iter().any(|f| {
-        f.func_name == getter_name || f.new_name.as_ref().map_or(false, |n| n == &getter_name)
-    });
-
-    let setter_name = setter_name.unwrap_or_else(|| format!("set_{}", &name_for_func));
-    let has_setter_method = obj_info.functions.iter().any(|f| {
-        f.func_name == setter_name || f.new_name.as_ref().map_or(false, |n| n == &setter_name)
-    });
-
     let mut v = Vec::with_capacity(2);
 
-    if property.readable && !has_getter_method {
+    if let Some(getter_name) = getter_name {
         v.push(TypeStruct {
             parent: parent.clone(),
             ..TypeStruct::new(SType::Fn, &getter_name)
         });
     }
-    if property.writable && !property.construct_only && !has_setter_method {
+    if let Some(setter_name) = setter_name {
         v.push(TypeStruct {
             parent,
             ..TypeStruct::new(SType::Fn, &setter_name)
