@@ -188,7 +188,7 @@ impl Builder {
                                     "Box_<({})>",
                                     calls
                                         .iter()
-                                        .map(|c| format!("&{}", c.bound_name))
+                                        .map(|c| c.bound_name.to_string())
                                         .collect::<Vec<_>>()
                                         .join(", ")
                                 );
@@ -285,7 +285,7 @@ impl Builder {
                             )
                         } else if calls.iter().all(|c| c.scope.is_call()) {
                             format!(
-                                "&({})",
+                                "&mut ({})",
                                 calls
                                     .iter()
                                     .map(|c| format!("{}_data", c.name))
@@ -312,11 +312,15 @@ impl Builder {
                         is_mut: false,
                         value: Box::new(Chunk::Custom(format!(
                             "{}{}_data",
-                            if calls[0].scope.is_call() { "&" } else { "" },
+                            if calls[0].scope.is_call() {
+                                "&mut "
+                            } else {
+                                ""
+                            },
                             calls[0].name
                         ))),
                         type_: Some(Box::new(Chunk::Custom(if calls[0].scope.is_call() {
-                            format!("&{}", calls[0].bound_name)
+                            format!("&mut {}", calls[0].bound_name)
                         } else {
                             format!("Box_<{}>", calls[0].bound_name)
                         }))),
@@ -390,7 +394,7 @@ impl Builder {
             if full_type.is_none() {
                 if trampoline.scope.is_call() {
                     chunks.push(Chunk::Custom(format!(
-                        "let {0}_data: {1} = {0};",
+                        "let mut {0}_data: {1} = {0};",
                         trampoline.name, trampoline.bound_name
                     )));
                 } else {
@@ -401,7 +405,7 @@ impl Builder {
                 }
             } else if trampoline.scope.is_call() {
                 chunks.push(Chunk::Custom(format!(
-                    "let {0}_data: &{1} = &{0};",
+                    "let mut {0}_data: &mut {1} = &mut {0};",
                     trampoline.name, trampoline.bound_name
                 )));
             } else {
@@ -480,7 +484,15 @@ impl Builder {
                     ))),
                     type_: Some(Box::new(Chunk::Custom(
                         if !trampoline.scope.is_async() && !trampoline.scope.is_call() {
-                            format!("&{}", full_type.1)
+                            format!(
+                                "&{}",
+                                full_type
+                                    .1
+                                    .strip_prefix("Box_<")
+                                    .unwrap()
+                                    .strip_suffix(">")
+                                    .unwrap()
+                            )
                         } else {
                             full_type.1.clone()
                         },
@@ -512,7 +524,7 @@ impl Builder {
                         )));
                     } else {
                         body.push(Chunk::Custom(format!(
-                            "let callback = callback{}",
+                            "let callback = &callback{};",
                             if let Some(pos) = pos {
                                 format!(".{pos}")
                             } else {
@@ -1005,7 +1017,7 @@ impl Builder {
                 Chunk::FfiCallParameter {
                     transformation_type: TransformationType::ToGlibDirect {
                         name: if all_call {
-                            format!("super_callback{pos} as *const _ as *mut _")
+                            format!("super_callback{pos} as *mut _ as *mut _")
                         } else {
                             format!("Box_::into_raw(super_callback{pos}) as *mut _")
                         },
