@@ -90,6 +90,13 @@ fn ffi_inner(env: &Env, tid: library::TypeId, mut inner: String) -> Result {
                 ULong => "c_ulong",
                 Size => "size_t",
                 SSize => "ssize_t",
+                TimeT => "time_t",
+                OffT => "off_t",
+                DevT => "dev_t",
+                GidT => "gid_t",
+                PidT => "pid_t",
+                SockLenT => "socklen_t",
+                UidT => "uid_t",
                 Float => "c_float",
                 Double => "c_double",
                 UniChar => "u32",
