@@ -1,8 +1,8 @@
-use std::fmt;
-use std::str::FromStr;
+use std::{fmt, str::FromStr};
 
-#[derive(Debug, Clone, Copy, Eq, PartialEq)]
+#[derive(Default, Debug, Clone, Copy, Eq, PartialEq)]
 pub enum Visibility {
+    #[default]
     Public,
     Crate,
     Super,
@@ -24,12 +24,6 @@ impl Visibility {
     }
 }
 
-impl Default for Visibility {
-    fn default() -> Self {
-        Self::Public
-    }
-}
-
 impl fmt::Display for Visibility {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         f.write_str(self.export_visibility())
@@ -56,10 +50,7 @@ impl FromStr for Visibility {
             "super" => Ok(Self::Super),
             "private" => Ok(Self::Private),
             "crate" => Ok(Self::Crate),
-            e => Err(ParseVisibilityError(format!(
-                "Wrong visibility type '{}'",
-                e
-            ))),
+            e => Err(ParseVisibilityError(format!("Wrong visibility type '{e}'"))),
         }
     }
 }
