@@ -1,7 +1,8 @@
-use super::{error::TomlHelper, parsable::Parse};
 use log::error;
 use toml::Value;
 
+use super::{error::TomlHelper, parsable::Parse};
+
 #[derive(Clone, Debug)]
 pub struct Derive {
     pub names: Vec<String>,
@@ -9,7 +10,7 @@ pub struct Derive {
 }
 
 impl Parse for Derive {
-    fn parse(toml: &Value, object_name: &str) -> Option<Derive> {
+    fn parse(toml: &Value, object_name: &str) -> Option<Self> {
         let names = match toml.lookup("name").and_then(Value::as_str) {
             Some(names) => names,
             None => {
@@ -17,10 +18,7 @@ impl Parse for Derive {
                 return None;
             }
         };
-        toml.check_unwanted(
-            &["name", "cfg_condition"],
-            &format!("derive {}", object_name),
-        );
+        toml.check_unwanted(&["name", "cfg_condition"], &format!("derive {object_name}"));
 
         let cfg_condition = toml
             .lookup("cfg_condition")
@@ -32,7 +30,7 @@ impl Parse for Derive {
             names_vec.push(name.trim().into());
         }
 
-        Some(Derive {
+        Some(Self {
             names: names_vec,
             cfg_condition,
         })
