@@ -1,13 +1,14 @@
-use super::TAB;
 use std::io::{Result, Write};
 
+use super::TAB;
+
 pub struct Untabber {
     orig: Box<dyn Write>,
 }
 
 impl Untabber {
-    pub fn new(orig: Box<dyn Write>) -> Untabber {
-        Untabber { orig }
+    pub fn new(orig: Box<dyn Write>) -> Self {
+        Self { orig }
     }
 }
 
